Api class

Constructors

Api()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chatCompletion({required ChatRequest request}) → Future<ChatCompletion?>
completionStream({required CompletionRequest request}) → Stream<Completion>?
Method to do text completion based on the given
generateImage({required ImageRequest request}) → Future<Images?>
Method to generate the image(s) based on the given
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCompletion({required CompletionRequest request}) → Future<Completion?>
Method to do text completion based on the given
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited