ChatGPT class

Constructors

ChatGPT()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chatCompletion({required ChatRequest request}) → Future<ChatCompletion?>
completionStream({required CompletionRequest request}) → Stream<Completion>
generateImage({required ImageRequest request}) → Future<Images?>
Image Generation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textCompletion({required CompletionRequest request}) → Future<Completion?>
Text API
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

token → String?
no setter

Static Methods

builder({required String token}) → ChatGPT
Builder @param token token to access the openAPI endpoints generate token here https://beta.openai.com/account/api-keys