ChatChoice class

Constructors

ChatChoice({ChatMessage? message, int? index, String? finishReason})
ChatChoice.fromMap(Map<String, dynamic> json)
factory

Properties

finishReason → String?
final
hashCode → int
The hash code for this object.
no setterinherited
index → int?
final
message → ChatMessage?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited