ChatRequest class

Constructors

ChatRequest({String? model = 'gpt-3.5-turbo', required List<ChatMessage> messages, double? temperature = 0.3, int? maxTokens = 50, double? topP = 0, double? presencePenalty = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxTokens → int?
final
messages → List<ChatMessage>
final
model → String?
final
presencePenalty → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → double?
final
topP → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited