Completion class

Constructors

Completion({String? id, String? object, int? created, String? model, List<Choice>? choices, Usage? usage})
Completion.fromMap(Map<String, dynamic> json)
factory

Properties

choices → List<Choice>?
final
created → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
model → String?
final
object → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → Usage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited