Usage class

Constructors

Usage({int? promptTokens, int? completionTokens, int? totalTokens})
Usage.fromJson(String source)
factory
Usage.fromMap(Map<String, dynamic> json)
factory

Properties

completionTokens → int?
final
hashCode → int
The hash code for this object.
no setterinherited
promptTokens → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTokens → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited